MethodChannelPolyvLiveScenes class

An implementation of PolyvLiveScenesPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String?>
override
loginLiveRoom({required int channelType, required String channelId, required String userId, required String appId, required String appSecret, String? viewerName, String? viewerAvatar}) Future<Map<String, dynamic>>
登录并进入保利威原生直播观看页。
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited