PolyvLiveScenesPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- PolyvLiveScenesPlatform
- Implementers
Constructors
- PolyvLiveScenesPlatform()
- Constructs a PolyvLiveScenesPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
loginLiveRoom(
{required int channelType, required String channelId, required String userId, required String appId, required String appSecret, String? viewerName, String? viewerAvatar}) → Future< Map< String, dynamic> > - 登录并进入保利威原生直播观看页。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PolyvLiveScenesPlatform
-
The default instance of PolyvLiveScenesPlatform to use.
getter/setter pair